==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Nef_2/group__PkgNef2Ref.js <==
var group__PkgNef2Ref =
[
    [ "Concepts", "group__PkgNef2Concepts.html", "group__PkgNef2Concepts" ],
    [ "Extended_cartesian", "classCGAL_1_1Extended__cartesian.html", [
      [ "Extended_cartesian", "classCGAL_1_1Extended__cartesian.html#aab724100b28e792ba95245c3971c443d", null ]
    ] ],
    [ "Extended_homogeneous", "classCGAL_1_1Extended__homogeneous.html", [
      [ "Extended_homogeneous", "classCGAL_1_1Extended__homogeneous.html#a5146f012b7fe8a357414f82bec0e0ed5", null ]
    ] ],
    [ "Filtered_extended_homogeneous", "classCGAL_1_1Filtered__extended__homogeneous.html", [
      [ "Filtered_extended_homogeneous", "classCGAL_1_1Filtered__extended__homogeneous.html#a2a1602b6e04038051387bfb5768d9bd2", null ]
    ] ],
    [ "Topological_explorer", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html", [
      [ "Halfedge_around_face_const_circulator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a3d91599845191e23b857636b90205901", null ],
      [ "Halfedge_around_vertex_const_circulator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa6e9ad3f6a1f4b942521defecf131ecc", null ],
      [ "Hole_const_iterator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa98d28ac00f9737daa2f6f31b5d93b76", null ],
      [ "Isolated_vertex_const_iterator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ae70494c101218e03667b280a2716caa5", null ],
      [ "Mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ab9c3cb93281bfc404d85509588283b95", null ],
      [ "Plane_map", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#abab9b23b8cd49905df2f86d587c7047a", null ],
      [ "Point", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0b8b294561b30ba955e5da673b832a66", null ],
      [ "Size_type", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#acb8098727c4c74aeed246539241dcc9e", null ],
      [ "check_integrity_and_topological_planarity", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#afb7f9daf17bd42853ac4586196ed4ec4", null ],
      [ "cyclic_adj_pred", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a6e1e557802ab55942df3e3055136a053", null ],
      [ "cyclic_adj_succ", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aafbb03fdd865ef605b2db27d0ca3acf8", null ],
      [ "face", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a2358b27ad254251fc31e296fdfe5d419", null ],
      [ "face", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a9b920d31bf43c6c904db5455e37efbfd", null ],
      [ "face_cycle", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aecb68b9f586e1c6cd28aab92eee16118", null ],
      [ "faces_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aaf2d8f8ab3be8fd8e18c1cac52a759da", null ],
      [ "faces_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#acec5c364e27fe70974b590e2980b20e8", null ],
      [ "first_out_edge", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#afadd9bb47ec1288d30f1d70f6b4da32e", null ],
      [ "halfedge", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a8a7c3d09bf639c6edba3aab3b5212164", null ],
      [ "halfedges_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ad73871d78bfe1e4e5b72585964715fda", null ],
      [ "halfedges_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a4600e41006af71fd70d01a7f87710a33", null ],
      [ "holes_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a3cf9b254ef4179ac4c4819c71999622a", null ],
      [ "holes_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a24e388badee0e933d0c60589a591dc7a", null ],
      [ "is_isolated", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0e911d8f84babfdaae4273499c62c792", null ],
      [ "isolated_vertices_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a004e8710a276682cb6324e0241fdc577", null ],
      [ "isolated_vertices_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ab1fec0a1ddc1b841cec1b38705bf5fa4", null ],
      [ "last_out_edge", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ac67872a8717d99a457f140be71dbd5cb", null ],
      [ "mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ae87b8d48eb9c4ec0d6537b08ccb2e688", null ],
      [ "mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a7a0eb4a3679d29256aca17d712775138", null ],
      [ "mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a38509dd5320957f5441d374528a3e78e", null ],
      [ "next", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a4723a70ebbe2377cc027bf4b5a2937ed", null ],
      [ "number_of_connected_components", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa4aa21d6219a42e2516f6bfb31335bdc", null ],
      [ "number_of_edges", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aaadbdb973504c741a13667efff8e5774", null ],
      [ "number_of_face_cycles", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a6a67d0fb0d7301a975cf1c1bdd0e2afd", null ],
      [ "number_of_faces", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a290e02ff14aebbf8ff48295bedbbcd74", null ],
      [ "number_of_halfedges", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a91d520c495d3bf2b14a5f206753eacf8", null ],
      [ "number_of_vertices", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a1c6b0ba373b73d72d4be6eaa9424e10f", null ],
      [ "out_edges", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ac80a554295d47ba89588bc7504914adf", null ],
      [ "point", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#acd1ce058d8a326a437463210b1088231", null ],
      [ "previous", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ace5fa684156afa58b25ddbece1098977", null ],
      [ "print_statistics", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0f1ca70f56988702a5c8c2a5b567c5ea", null ],
      [ "source", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa5fa0f1f1f776119ec0bf846eb9221db", null ],
      [ "target", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0e8e59558528450d58b0722990fbc3cc", null ],
      [ "twin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a4d947b1cd5d82b500a9a5fd6d50dd908", null ],
      [ "vertices_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0b63cd235f06f5d1f55c3e91f29bb1de", null ],
      [ "vertices_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a45e030bdaa0a09e4ccec3474dbb21f1c", null ]
    ] ],
    [ "Explorer", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html", [
      [ "Point", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a4c071b62dc69909b967d78b38730b061", null ],
      [ "Ray", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a52c0b5ab73356ed694f18353f6129855", null ],
      [ "is_frame_edge", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a458086c5948d8a192b805ecdfd0712e2", null ],
      [ "is_standard", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#ae9e9ce49f9aed3a634c0adca2fc25268", null ],
      [ "point", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#af13f09b7bb5e67dcf92a7ad55aba82bb", null ],
      [ "ray", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a0f76bb79a851ef64a69406c2fc8b54db", null ]
    ] ],
    [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html", [
      [ "Direction", "classCGAL_1_1Nef__polyhedron__2.html#ac5779dcd0d9aa9007e4bafe0bceb3ae4", null ],
      [ "Line", "classCGAL_1_1Nef__polyhedron__2.html#a1e0e9aa5868dc87384c1cb65df4b2828", null ],
      [ "Object_handle", "classCGAL_1_1Nef__polyhedron__2.html#a2ae6d7ad3ab6fa5417b87d9cfec493af", null ],
      [ "Point", "classCGAL_1_1Nef__polyhedron__2.html#a5dba79fcf624dbb9e3163f68f4f75e00", null ],
      [ "Polygons_tag", "classCGAL_1_1Nef__polyhedron__2.html#ac640be6a8130703344a89ad4859d4867", null ],
      [ "Polylines_tag", "classCGAL_1_1Nef__polyhedron__2.html#afa372c8392eae26070c04575ec8d198d", null ],
      [ "Boundary", "classCGAL_1_1Nef__polyhedron__2.html#a8cb9d4db15905d56ae4be1d502aab8ff", [
        [ "EXCLUDED", "classCGAL_1_1Nef__polyhedron__2.html#a8cb9d4db15905d56ae4be1d502aab8ffa94a77215e20d6be276e5b7ec032c3139", null ],
        [ "INCLUDED", "classCGAL_1_1Nef__polyhedron__2.html#a8cb9d4db15905d56ae4be1d502aab8ffa8bca0012800a9d7df0cc129218be8b43", null ]
      ] ],
      [ "Content", "classCGAL_1_1Nef__polyhedron__2.html#ab5f1c19c50d23c0a759c2d2b1bb60bd0", [
        [ "EMPTY", "classCGAL_1_1Nef__polyhedron__2.html#ab5f1c19c50d23c0a759c2d2b1bb60bd0a4786fccb661c483062e02b784e1c722c", null ],
        [ "COMPLETE", "classCGAL_1_1Nef__polyhedron__2.html#ab5f1c19c50d23c0a759c2d2b1bb60bd0acbd2d7c6e526cfad582f001a6a0042a3", null ]
      ] ],
      [ "Location_mode", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abc", [
        [ "DEFAULT", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abcac595e6612a1f0c393f022857702887af", null ],
        [ "NAIVE", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abcaca828eed6da20a9383aeb13ef1dcdbed", null ],
        [ "LMWT", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abca775e12588827baac52ff0b8d3dec1616", null ]
      ] ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#ab4af61958347b01b464fb87ce06d7571", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#a5c6718ebe574d776b5cc9c767eff9acf", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#ab97de249020e516c3e6a599f18a1f745", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#ad68e86a3bdeddb587363bf73edaae184", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#af756cab6f8712b0aaaeddb72f6115aee", null ],
      [ "boundary", "classCGAL_1_1Nef__polyhedron__2.html#a5caead26e295b819211f52c2e616b568", null ],
      [ "clear", "classCGAL_1_1Nef__polyhedron__2.html#ad8a2c296b76e8bb29c715bbabac6654b", null ],
      [ "closure", "classCGAL_1_1Nef__polyhedron__2.html#a7250e12e77f1d7e64a773243cb413b8f", null ],
      [ "complement", "classCGAL_1_1Nef__polyhedron__2.html#a6d563177e49fd01a39e44f1183797a96", null ],
      [ "contained_in_boundary", "classCGAL_1_1Nef__polyhedron__2.html#ae40387867733e7ddc47f5a29f33cac02", null ],
      [ "contains", "classCGAL_1_1Nef__polyhedron__2.html#a8de0d51fb5bc6e9e73f87047fa0f1f3f", null ],
      [ "difference", "classCGAL_1_1Nef__polyhedron__2.html#a6a312aa40e2b58167279881c1d14d62f", null ],
      [ "explorer", "classCGAL_1_1Nef__polyhedron__2.html#a067bf42f1a6b9b13a6fcc45baa30299b", null ],
      [ "interior", "classCGAL_1_1Nef__polyhedron__2.html#a3b82c78fe42d878d9418023fe02590f9", null ],
      [ "intersection", "classCGAL_1_1Nef__polyhedron__2.html#ab341639df2691491b20e8adf96b94d62", null ],
      [ "is_empty", "classCGAL_1_1Nef__polyhedron__2.html#a5014cbf16cdb80a88729b259741bf16f", null ],
      [ "is_plane", "classCGAL_1_1Nef__polyhedron__2.html#ada3ed3315cae400bdfdfcac4c9be5bce", null ],
      [ "join", "classCGAL_1_1Nef__polyhedron__2.html#acfd32f367b34bb3fd67028b61082888b", null ],
      [ "locate", "classCGAL_1_1Nef__polyhedron__2.html#a1eca334fed696603f7bed85da151582c", null ],
      [ "ray_shoot", "classCGAL_1_1Nef__polyhedron__2.html#a59903a8983c436a9be57e4bf9d49cfd8", null ],
      [ "ray_shoot_to_boundary", "classCGAL_1_1Nef__polyhedron__2.html#a7e858bf751d797d0299e312238bd0688", null ],
      [ "regularization", "classCGAL_1_1Nef__polyhedron__2.html#a1d0ed6d7b4eb2a47d449c097cdc5cfff", null ],
      [ "symmetric_difference", "classCGAL_1_1Nef__polyhedron__2.html#ab33879f34f12f89054eff83437dd34f0", null ]
    ] ]
];

==> CGAL-6.0-doc_html.tar.xz: doc_html/Nef_2/group__PkgNef2Ref.js <==
var group__PkgNef2Ref =
[
    [ "Concepts", "group__PkgNef2Concepts.html", "group__PkgNef2Concepts" ],
    [ "CGAL::Extended_cartesian< FT >", "classCGAL_1_1Extended__cartesian.html", [
      [ "Extended_cartesian", "classCGAL_1_1Extended__cartesian.html#aab724100b28e792ba95245c3971c443d", null ]
    ] ],
    [ "CGAL::Extended_homogeneous< RT >", "classCGAL_1_1Extended__homogeneous.html", [
      [ "Extended_homogeneous", "classCGAL_1_1Extended__homogeneous.html#a5146f012b7fe8a357414f82bec0e0ed5", null ]
    ] ],
    [ "CGAL::Filtered_extended_homogeneous< RT >", "classCGAL_1_1Filtered__extended__homogeneous.html", [
      [ "Filtered_extended_homogeneous", "classCGAL_1_1Filtered__extended__homogeneous.html#a2a1602b6e04038051387bfb5768d9bd2", null ]
    ] ],
    [ "CGAL::Nef_polyhedron_2< T >", "classCGAL_1_1Nef__polyhedron__2.html", [
      [ "Direction", "classCGAL_1_1Nef__polyhedron__2.html#ac5779dcd0d9aa9007e4bafe0bceb3ae4", null ],
      [ "Line", "classCGAL_1_1Nef__polyhedron__2.html#a1e0e9aa5868dc87384c1cb65df4b2828", null ],
      [ "Object_handle", "classCGAL_1_1Nef__polyhedron__2.html#a2ae6d7ad3ab6fa5417b87d9cfec493af", null ],
      [ "Point", "classCGAL_1_1Nef__polyhedron__2.html#a5dba79fcf624dbb9e3163f68f4f75e00", null ],
      [ "Polygons_tag", "classCGAL_1_1Nef__polyhedron__2.html#ac640be6a8130703344a89ad4859d4867", null ],
      [ "Polylines_tag", "classCGAL_1_1Nef__polyhedron__2.html#afa372c8392eae26070c04575ec8d198d", null ],
      [ "Boundary", "classCGAL_1_1Nef__polyhedron__2.html#a8cb9d4db15905d56ae4be1d502aab8ff", [
        [ "EXCLUDED", "classCGAL_1_1Nef__polyhedron__2.html#a8cb9d4db15905d56ae4be1d502aab8ffa94a77215e20d6be276e5b7ec032c3139", null ],
        [ "INCLUDED", "classCGAL_1_1Nef__polyhedron__2.html#a8cb9d4db15905d56ae4be1d502aab8ffa8bca0012800a9d7df0cc129218be8b43", null ]
      ] ],
      [ "Content", "classCGAL_1_1Nef__polyhedron__2.html#ab5f1c19c50d23c0a759c2d2b1bb60bd0", [
        [ "EMPTY", "classCGAL_1_1Nef__polyhedron__2.html#ab5f1c19c50d23c0a759c2d2b1bb60bd0a4786fccb661c483062e02b784e1c722c", null ],
        [ "COMPLETE", "classCGAL_1_1Nef__polyhedron__2.html#ab5f1c19c50d23c0a759c2d2b1bb60bd0acbd2d7c6e526cfad582f001a6a0042a3", null ]
      ] ],
      [ "Location_mode", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abc", [
        [ "DEFAULT", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abcac595e6612a1f0c393f022857702887af", null ],
        [ "NAIVE", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abcaca828eed6da20a9383aeb13ef1dcdbed", null ],
        [ "LMWT", "classCGAL_1_1Nef__polyhedron__2.html#aa7cddcb2fffffe488f897da1f3cf4abca775e12588827baac52ff0b8d3dec1616", null ]
      ] ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#ab4af61958347b01b464fb87ce06d7571", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#a5c6718ebe574d776b5cc9c767eff9acf", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#ab97de249020e516c3e6a599f18a1f745", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#ad68e86a3bdeddb587363bf73edaae184", null ],
      [ "Nef_polyhedron_2", "classCGAL_1_1Nef__polyhedron__2.html#af756cab6f8712b0aaaeddb72f6115aee", null ],
      [ "boundary", "classCGAL_1_1Nef__polyhedron__2.html#ac470e4f51ea938cbda3fbef705f225ec", null ],
      [ "clear", "classCGAL_1_1Nef__polyhedron__2.html#ad8a2c296b76e8bb29c715bbabac6654b", null ],
      [ "closure", "classCGAL_1_1Nef__polyhedron__2.html#ab590d816fbe6fae5d1503a461a6a52f4", null ],
      [ "complement", "classCGAL_1_1Nef__polyhedron__2.html#afe15ea80568bc19adfc9a78b61d94b9d", null ],
      [ "contained_in_boundary", "classCGAL_1_1Nef__polyhedron__2.html#ae40387867733e7ddc47f5a29f33cac02", null ],
      [ "contains", "classCGAL_1_1Nef__polyhedron__2.html#a8de0d51fb5bc6e9e73f87047fa0f1f3f", null ],
      [ "difference", "classCGAL_1_1Nef__polyhedron__2.html#a82bb8df64f83bfa57cf8e6e7657dc5d7", null ],
      [ "explorer", "classCGAL_1_1Nef__polyhedron__2.html#a067bf42f1a6b9b13a6fcc45baa30299b", null ],
      [ "interior", "classCGAL_1_1Nef__polyhedron__2.html#ac2ab0eb5ebce64cfae2f0ef7a781fa99", null ],
      [ "intersection", "classCGAL_1_1Nef__polyhedron__2.html#a54fc43261c9f44822f8f5ef9cf457c98", null ],
      [ "is_empty", "classCGAL_1_1Nef__polyhedron__2.html#a5014cbf16cdb80a88729b259741bf16f", null ],
      [ "is_plane", "classCGAL_1_1Nef__polyhedron__2.html#ada3ed3315cae400bdfdfcac4c9be5bce", null ],
      [ "join", "classCGAL_1_1Nef__polyhedron__2.html#aa97b20003d4c31bf0cc9bf611c4258bc", null ],
      [ "locate", "classCGAL_1_1Nef__polyhedron__2.html#a1eca334fed696603f7bed85da151582c", null ],
      [ "ray_shoot", "classCGAL_1_1Nef__polyhedron__2.html#a59903a8983c436a9be57e4bf9d49cfd8", null ],
      [ "ray_shoot_to_boundary", "classCGAL_1_1Nef__polyhedron__2.html#a7e858bf751d797d0299e312238bd0688", null ],
      [ "regularization", "classCGAL_1_1Nef__polyhedron__2.html#afe97139024ff9e43b1301fe3cc26dd01", null ],
      [ "symmetric_difference", "classCGAL_1_1Nef__polyhedron__2.html#a9da7a1f021accae1db53304ec0c07e14", null ]
    ] ],
    [ "CGAL::Nef_polyhedron_2< T >::Topological_explorer", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html", [
      [ "Halfedge_around_face_const_circulator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a3d91599845191e23b857636b90205901", null ],
      [ "Halfedge_around_vertex_const_circulator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa6e9ad3f6a1f4b942521defecf131ecc", null ],
      [ "Hole_const_iterator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa98d28ac00f9737daa2f6f31b5d93b76", null ],
      [ "Isolated_vertex_const_iterator", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ae70494c101218e03667b280a2716caa5", null ],
      [ "Mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ab9c3cb93281bfc404d85509588283b95", null ],
      [ "Plane_map", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#abab9b23b8cd49905df2f86d587c7047a", null ],
      [ "Point", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0b8b294561b30ba955e5da673b832a66", null ],
      [ "Size_type", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#acb8098727c4c74aeed246539241dcc9e", null ],
      [ "check_integrity_and_topological_planarity", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#afb7f9daf17bd42853ac4586196ed4ec4", null ],
      [ "cyclic_adj_pred", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a6e1e557802ab55942df3e3055136a053", null ],
      [ "cyclic_adj_succ", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aafbb03fdd865ef605b2db27d0ca3acf8", null ],
      [ "face", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a2358b27ad254251fc31e296fdfe5d419", null ],
      [ "face", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a9b920d31bf43c6c904db5455e37efbfd", null ],
      [ "face_cycle", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aecb68b9f586e1c6cd28aab92eee16118", null ],
      [ "faces_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aaf2d8f8ab3be8fd8e18c1cac52a759da", null ],
      [ "faces_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#acec5c364e27fe70974b590e2980b20e8", null ],
      [ "first_out_edge", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#afadd9bb47ec1288d30f1d70f6b4da32e", null ],
      [ "halfedge", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a8a7c3d09bf639c6edba3aab3b5212164", null ],
      [ "halfedges_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ad73871d78bfe1e4e5b72585964715fda", null ],
      [ "halfedges_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a4600e41006af71fd70d01a7f87710a33", null ],
      [ "holes_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a3cf9b254ef4179ac4c4819c71999622a", null ],
      [ "holes_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a24e388badee0e933d0c60589a591dc7a", null ],
      [ "is_isolated", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0e911d8f84babfdaae4273499c62c792", null ],
      [ "isolated_vertices_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a004e8710a276682cb6324e0241fdc577", null ],
      [ "isolated_vertices_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ab1fec0a1ddc1b841cec1b38705bf5fa4", null ],
      [ "last_out_edge", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ac67872a8717d99a457f140be71dbd5cb", null ],
      [ "mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ae43bd74d1ddd0ac68bdfb66d93fcc7b4", null ],
      [ "mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a3a97fcfb8f3d8b33ff32659dec3d54a4", null ],
      [ "mark", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ac24cb67996cd68ff7caef3e39037b4de", null ],
      [ "next", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a4723a70ebbe2377cc027bf4b5a2937ed", null ],
      [ "number_of_connected_components", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa4aa21d6219a42e2516f6bfb31335bdc", null ],
      [ "number_of_edges", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aaadbdb973504c741a13667efff8e5774", null ],
      [ "number_of_face_cycles", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a6a67d0fb0d7301a975cf1c1bdd0e2afd", null ],
      [ "number_of_faces", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a290e02ff14aebbf8ff48295bedbbcd74", null ],
      [ "number_of_halfedges", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a91d520c495d3bf2b14a5f206753eacf8", null ],
      [ "number_of_vertices", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a1c6b0ba373b73d72d4be6eaa9424e10f", null ],
      [ "out_edges", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ac80a554295d47ba89588bc7504914adf", null ],
      [ "point", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ad9faee1d0176ba60e4ae4b40546776f8", null ],
      [ "previous", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#ace5fa684156afa58b25ddbece1098977", null ],
      [ "print_statistics", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0f1ca70f56988702a5c8c2a5b567c5ea", null ],
      [ "source", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#aa5fa0f1f1f776119ec0bf846eb9221db", null ],
      [ "target", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0e8e59558528450d58b0722990fbc3cc", null ],
      [ "twin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a4d947b1cd5d82b500a9a5fd6d50dd908", null ],
      [ "vertices_begin", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a0b63cd235f06f5d1f55c3e91f29bb1de", null ],
      [ "vertices_end", "classCGAL_1_1Nef__polyhedron__2_1_1Topological__explorer.html#a45e030bdaa0a09e4ccec3474dbb21f1c", null ]
    ] ],
    [ "CGAL::Nef_polyhedron_2< T >::Explorer", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html", [
      [ "Point", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a4c071b62dc69909b967d78b38730b061", null ],
      [ "Ray", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a52c0b5ab73356ed694f18353f6129855", null ],
      [ "is_frame_edge", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a458086c5948d8a192b805ecdfd0712e2", null ],
      [ "is_standard", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#ae9e9ce49f9aed3a634c0adca2fc25268", null ],
      [ "point", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#af13f09b7bb5e67dcf92a7ad55aba82bb", null ],
      [ "ray", "classCGAL_1_1Nef__polyhedron__2_1_1Explorer.html#a0f76bb79a851ef64a69406c2fc8b54db", null ]
    ] ]
];
